
Include "parameters.pro";

Group {
  cavity = Region[{1001}];
  sides     = Region[{101}];
  inlet     = Region[{102}];
  outlet    = Region[{103}];

  Domain2D= Region[{cavity}];
  Domain1D= Region[{sides,inlet,outlet}];
  Domain = Region[{Domain2D,Domain1D}];
}

Function {
	I[]=Complex[0.0,1.0];
	TimeFct[]=prms*Cos[2.*Pi*$Time];
 }

Constraint {
  { Name zero; 
    Case {
         { Region inlet ; Type Assign; Value prms; TimeFunction  TimeFct[] ; }
    }
  }
}

/* Standard Jacobian */
Jacobian {
  { Name Jac;
    Case { { Region Domain2D; Jacobian Vol; }
           { Region Domain1D; Jacobian Sur; }
    }
  }
}

/* Standard integration */
Integration {
  { Name I1 ;
    Case {
      { Type Gauss ;
        Case {
              { GeoElement Triangle ; NumberOfPoints  4; }
              { GeoElement Line     ; NumberOfPoints  3; }
              { GeoElement Point    ; NumberOfPoints  1; }
        }
      }
    }
  }
}

FunctionSpace {
    // 1st order nodal elements
    { Name form0_1st; Type Form0 ;
     BasisFunction {
		{ Name se ; NameOfCoef ae ; Function BF_Node;
			Support Domain2D ; Entity NodesOf[ All ] ; }
		{ Name s2; NameOfCoef v2; Function BF_Node_2E; 
			Support Domain2D; Entity EdgesOf[All];}
    }
    Constraint {
      { NameOfCoef ae ; EntityType NodesOf ; NameOfConstraint zero ; }
	  { NameOfCoef v2; EntityType EdgesOf; NameOfConstraint zero;}
      }
    }
}

Formulation {
  { Name form; Type FemEquation;
    Quantity {
      { Name psi;  Type Local; NameOfSpace form0_1st;}
   }
    Equation {
      /* 2D domain terms */
      Galerkin {      [ -Dof{d psi},{d psi} ]; In Domain2D; Integration I1; Jacobian Jac;}
      Galerkin {       DtDt[1/c^2*Dof{psi},{psi} ]; In Domain2D; Integration I1; Jacobian Jac;}
      /* Boundary terms */
	  Galerkin {      [ -I[]*rho*omega/Z*Dof{psi},{psi} ]; In sides; Integration I1; Jacobian Jac;}
      /* Outlet */
	  Galerkin {      [ -I[]*rho*omega/Z*Dof{psi},{psi} ]; In outlet; Integration I1; Jacobian Jac;}
             }
  }
}

Resolution {
   { Name res_static;
    System
    {
      { Name A; NameOfFormulation form; Type ComplexValue;}
    }
    Operation {
		InitSolution[A];
        TimeLoopTheta[0,0.01,0.001,0.5]{Generate[A] ; Solve[A] ; SaveSolution[A]; }
        }
    }
}

PostProcessing {
  { Name postproc; NameOfFormulation form; Quantity
    {
//		{ Name Decibels;  Value { Local{ [20*Log[Norm[{psi}]/pref]/Log[10]]   ; In Domain; Jacobian Jac; } } }
		{ Name p_rms;  Value { Local{ [Norm[{psi}]]   ; In Domain; Jacobian Jac; } } }
       }
  }
}

PostOperation {
   { Name sound_pressure; NameOfPostProcessing postproc;  Operation
    {
//		Print [ Decibels, OnElementsOf Domain2D, File "Decibels.pos"];
		Print [ p_rms, OnElementsOf Domain2D, File "p_rms.pos"];
    }
  }
}